@@ -15,6 +15,7 @@ from .nodetrees import set_material_socket  # noqa
 from .nodetrees import set_world_socket  # noqa
 from .objects import ULCurve  # noqa
 from .objects import controller_brick_status  # noqa
+from .objects import controller_brick  # noqa
 from .objects import create_curve  # noqa
 from .objects import set_curve_points  # noqa
 from .raycasting import raycast  # noqa
@@ -26,10 +27,14 @@ from .scene import set_scene  # noqa
 from .visuals import draw_box  # noqa
 from .visuals import draw_cube  # noqa
 from .visuals import draw_line  # noqa
+from .visuals import draw_points  # noqa
+from .scene import FileLoader  # noqa
+from .scene import SceneLoader  # noqa
 from bge import logic
 from bge.types import KX_GameObject as GameObject
 from mathutils import Matrix
 from mathutils import Vector
+import time as t
 
 import bpy
 import json
@@ -368,46 +373,6 @@ def rot_to(
         )
 
 
-###############################################################################
-# DATA
-###############################################################################
-
-def load_json_as_dict(filepath):
-    if not filepath.endswith('.json'):
-        filepath = f'{filepath}.json'
-    if filepath:
-        f = open(filepath, 'r')
-        data = json.load(f)
-        f.close()
-        return data
-    else:
-        raise FileNotFoundError(f'File {filepath} could not be opened!')
-
-
-class MaterialLoader():
-
-    def __init__(self, game_object):
-        self.status = 0.0
-        self.game_object = game_object
-        if len(game_object.blenderObject.material_slots) < 1:
-            debug('MaterialLoader object needs at least one material slot!')
-            return
-        self.materials = [m for m in bpy.data.materials]
-        logic.getCurrentScene().pre_draw.append(self.load_next)
-
-    def load_next(self):
-        next_mat = self.materials.pop()
-        self.game_object.blenderObject.material_slots[0].material = next_mat
-        self.status += 1 / len(bpy.data.materials)
-        if not self.materials:
-            logic.getCurrentScene().pre_draw.remove(self.load_next)
-            self.on_finish()
-
-    def on_finish(self):
-        pass
-
-
-
 ###############################################################################
 # SCENE
 ###############################################################################
@@ -471,6 +436,24 @@ def clamp(value: float or Vector, min: float = 0, max: float = 1) -> float:
     return value
 
 
+def cycle(value: float or Vector, min: float = 0, max: float = 1) -> float:
+    """Clamp a value in between two other values.
+
+    :param value: input value
+    :param min: minimum value
+    :param max: maximum value
+
+    :returns: clamped value as float
+    """
+    if isinstance(value, Vector):
+        return vec_clamp(value, min, max)
+    if value < min:
+        return max
+    if value > max:
+        return min
+    return value
+
+
 def vec_clamp(vec: Vector, min: float = 0, max: float = 1) -> Vector:
     """Clamp length of a vector.
 
@@ -599,7 +582,7 @@ def map_range(value: float, in_min: float, in_max: float, out_min: float, out_ma
     return result
 
 
-def screen_to_world(x=None, y=None, distance=10) -> Vector:
+def screen_to_world(x:float = None, y: float = None, distance: float = 10) -> Vector:
     """Get the world coordinates of a point on the screen in a given distance.
     
     :param `x`: X position on the screen. Leave at `None` to use mouse position.
@@ -618,6 +601,7 @@ def screen_to_world(x=None, y=None, distance=10) -> Vector:
     aim = direction * -distance
     return origin + (aim)
 
+
 def mouse_over(game_object: GameObject) -> bool:
     scene = game_object.scene
     camera = scene.active_camera
@@ -631,5 +615,28 @@ def mouse_over(game_object: GameObject) -> bool:
     )
     return target is game_object
 
+
 def get_local(obj, target) -> Matrix:
-    return obj.worldTransform.inverted() @ target
\ No newline at end of file
+    return obj.worldTransform.inverted() @ target
+
+
+def get_collision_bitmask(
+    slot_0: float = 1,
+    slot_1: float = 1,
+    slot_2: float = 1,
+    slot_3: float = 1,
+    slot_4: float = 1,
+    slot_5: float = 1,
+    slot_6: float = 1,
+    slot_7: float = 1,
+    slot_8: float = 1,
+    slot_9: float = 1,
+    slot_10: float = 1,
+    slot_11: float = 1,
+    slot_12: float = 1,
+    slot_13: float = 1,
+    slot_14: float = 1,
+    slot_15: float = 1
+) -> int:
+    slots = [slot_0, slot_1, slot_2, slot_3, slot_4, slot_5, slot_6, slot_7, slot_8, slot_9, slot_10, slot_11, slot_12, slot_13, slot_14, slot_15]
+    return sum([slots[idx] * (2**idx) for idx in range(16)])
